@@ -10,23 +10,19 @@ use URI::Escape qw(uri_escape_utf8);
 use Compress::Zlib;
 use XML::LibXML;
 use Carp qw(confess);
-use Encode;
-use Time::HiRes qw/gettimeofday tv_interval/;
-
 use Masterkey::Admin::Record;
 use Masterkey::Admin::ResultSet;
 use Masterkey::Admin::Parent;
 use Masterkey::Admin::Master;
 use Masterkey::Admin::Properties;
 
+
 our $using_XML_LibXML_Simple;
 
 BEGIN {
     # Use XML::LibXML::Simple when possible, but it's not available on
     # all platforms (e.g. MacOS X v10.5.8) so be prepared to back down
-    # to XML::Simple. Pathetically, the API of XML::LibXML::Simple is
-    # not backwards compatible, so we need to know which we're
-    # using. Sheesh.
+    # to XML::Simple.
     eval {
 	require 'XML/LibXML/Simple.pm';
 	import XML::LibXML::Simple;
@@ -44,7 +40,7 @@ sub new {
     my $class = shift();
     my($admin, $ws) = @_;
 
-    die "WARNING: making $class with non-torus2 WS '$ws'"
+    warn "WARNING: making $class with non-torus2 WS '$ws'"
 	if $ws !~ /\/torus2\//;
 
     my $this = bless {
@@ -347,6 +343,14 @@ sub _recordByArgs {
 }
 
 
+sub recordURI {
+    my $this = shift();
+    my($listType, $realm, $id) = @_;
+
+    return $this->recordURIbyArgs(listType => $listType, realm => $realm, id => $id);
+}
+
+
 sub recordURIbyArgs {
     my $this = shift();
     my(%args) = @_;
@@ -371,34 +375,16 @@ sub _getAsXML {
     my($uri) = @_;
 
     my $res = $this->_get($uri);
-    my $xml = $res->decoded_content('default_charset' => 'UTF-8')
+    my $xml = $res->content()
 	or die "no content for '$uri'";
 
     return XMLin($xml, ForceArray => 1, KeyAttr => []);
 }
 
-sub time_diff {
-    my $this = shift;
-    my $t0 = shift || $this->{'_time_start'};
-
-    # time im milli seconds
-    my $elapsed = int(tv_interval($t0) * 1000);
-
-    return $elapsed;
-}
-
-sub time_start {
-    my $this = shift;
-
-    return $this->{'_time_start'} = [gettimeofday];
-}
-
 sub _get {
     my $this = shift();
     my($uri) = @_;
 
-    $this->time_start;
-
     if ($uri =~ /^file:/) {
 	# Hack needed for when we make fake Toruses in the filesystem,
 	# since we can't have a file and a directory of the same name.
@@ -406,13 +392,9 @@ sub _get {
 	$uri .= ".xml";
     }
 
-
+    $this->log(Masterkey::Admin::LogLevel::TORUS, "GET $uri");
     my $res = $this->{ua}->get($uri, "Accept-Encoding" => "gzip")
 	or die "no response for '$uri'\n";
-
-    my $elapsed = $this->time_diff;
-    $this->log(Masterkey::Admin::LogLevel::TORUS, "GET $uri [$elapsed ms]");
-
     $this->_decompress_content($res); ### Why doesn't LWP do this itself?
     if (!$res->is_success()) {
 	$this->_http_fatal("GET", $uri, $res);
@@ -432,6 +414,41 @@ sub _get {
     return $res;
 }
 
+sub _put {
+    my $this = shift();
+    my($uri, $xml) = @_;
+
+    $this->log(Masterkey::Admin::LogLevel::TORUS, "PUT $uri");
+    $this->log(Masterkey::Admin::LogLevel::WSPUT, $xml);
+    my $res = $this->{ua}->request(PUT($uri, Content => $xml,
+		   "Content-Type" => "application/xml"))
+	or die "no response for PUT to '$uri'\n";
+
+    if (!$res->is_success()) {
+	$this->_http_fatal("PUT to", $uri, $res);
+    }
+
+    return $res;
+}
+
+sub _post {
+    my $this = shift();
+    my($uri, $xml) = @_;
+
+    $this->log(Masterkey::Admin::LogLevel::TORUS, "POST $uri");
+    $this->log(Masterkey::Admin::LogLevel::WSPOST, $xml);
+    my $res = $this->{ua}->request(POST($uri, Content => $xml,
+		   "Content-Type" => "application/xml"))
+	or die "no response for POST to '$uri'\n";
+
+    if (!$res->is_success()) {
+	$this->_http_fatal("POST to", $uri, $res);
+    }
+
+    return $res;
+}
+
+
 sub _decompress_content {
     my $this = shift();
     my($res) = @_;
@@ -444,60 +461,14 @@ sub _decompress_content {
 	$res->content($content);
 	$res->header("content-encoding" => "");
     	$this->log(Masterkey::Admin::LogLevel::COMPRESS,
-		   "decompressed $oldlength to ", length($content), " bytes ",
+		   "decompressed $oldlength to ", length($content), " chars ",
 		   "(", int(100 * $oldlength / length($content)), "%)");
     } else {
     	$this->log(Masterkey::Admin::LogLevel::COMPRESS,
-		   "read ", length($res->content()), " bytes, not compressed");
+		   "read ", length($res->content()), " chars, not compressed");
     }
 }
 
-# convert unicode characters to bytes before sending
-# it over the wire. Use it for all data exchanges with
-# external APIs!
-sub unicode2octets {
-    my $data = shift;
-
-    return Encode::encode( "utf-8", $data, Encode::FB_DEFAULT );
-}
-
-sub _put {
-    my $this = shift();
-    return $this->_put_or_post('PUT', Masterkey::Admin::LogLevel::WSPUT, \&PUT, @_);
-}
-
-sub _post {
-    my $this = shift();
-    return $this->_put_or_post('POST', Masterkey::Admin::LogLevel::WSPOST, \&POST, @_);
-}
-
-sub _put_or_post {
-    my $this = shift();
-    my($label, $loglevel, $method, $uri, $xml) = @_;
-
-    $this->log($loglevel, "data is utf8: " . Encode::is_utf8($xml));
-    if (!Encode::is_utf8($xml)) {
-    	$this->log($loglevel, "XML is not utf8, set utf8 flag");
-    	Encode::_utf8_on($xml) if !Encode::is_utf8($xml);
-    }
-    $xml = &unicode2octets($xml);
-
-    $this->log($loglevel, $xml);
-    $this->time_start;
-    my $res = $this->{ua}->request($method->($uri, Content => $xml,
-		   "Content-Type" => "application/xml"))
-	or die "no response for $label to '$uri'\n";
-
-    my $elapsed = $this->time_diff;
-    $this->log(Masterkey::Admin::LogLevel::TORUS, "x$label $uri [$elapsed ms]");
-
-    if (!$res->is_success()) {
-	$this->_http_fatal("$label to", $uri, $res);
-    }
-
-    return $res;
-}
-
 
 # $goneHash is a reference to a hash whose keys are the names of
 # fields that should be removed completely from the record.
@@ -696,7 +667,7 @@ sub _hash2cql {
 	$val =~ s/[""*?]/\\$&/g;
 	qq[$_=="$val"];
     } sort keys %args);
-
+    
     return $query;
 }
 
@@ -705,7 +676,7 @@ sub _http_fatal {
     my($method, $uri, $res) = @_;
 
     my $message = "can't $method '$uri': " . $res->message();
-    my $content = $res->decoded_content('default_charset' => 'UTF-8');
+    my $content = $res->content();
     $message .= " ($content)" if defined $content && $content ne "";
     $message .= "\n";
     warn $message; # For the HTTP server log
